package com.miyzh.service;

import com.miyzh.dao.OrderDetailDao;
import com.miyzh.entity.Clinic;
import com.miyzh.entity.MedicineReturn;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Slf4j
@Service
public class BaseService {

    @Autowired
    private ClinicService clinicService;

    @Autowired
    private MedicineStoreService medicineStoreService;

    @Autowired
    private MedicineStorageService medicineStorageService;

    @Autowired
    private MedicineReturnService medicineReturnService;

    @Autowired
    private OrderDetailService orderDetailService;

    private class OutStore {
        private static final String MED_OUT = "1"; //西药销售出库记录
        private static final String CHI_MED_OUT = "2"; //中药销售出库记录
        private static final String MED_OUTTREASURY = "3"; //西药损耗/领用出库记录
        private static final String CHI_MED_OUTTREASURY = "4"; //中药损耗/领用出库记录
        private static final String MED_BACK = "5"; //西药采购退货出库记录
        private static final String CHI_MED_BACK = "6"; //中药采购退货出库记录
        private static final String MED_INV = "7"; //西药盘点盘亏出库记录
        private static final String CHI_MED_INV = "8"; //中药盘点盘亏出库记录
    }

    private class InStore {
        private static final String MED_PUR = "1"; //西药采购入库
        private static final String CHI_MED_PUR = "2"; //中药采购入库
        private static final String MED_MED_INBOUND = "3"; //西药销售退回入库
        private static final String CHI_MED_INBOUND = "4"; //中药销售退回
        private static final String MED_INV = "5"; //西药盘盈入库
        private static final String CHI_MED_INV = "6"; //中药盘盈入库
    }

    private class OrderDetail {
        private static final String CLI_MED = "1"; //西药销售明细记录(自费门诊)
        private static final String CLI_CHI_MED = "2"; //西药销售明细记录(医保门诊)
        private static final String INS_CLC_MED = "3"; // 中药销售明细记录(自费门诊)
        private static final String INS_CLC_CHI_MED = "4"; // 中药销售明细记录(医保门诊)
        private static final String HOS_MED = "5"; // 西药药销售明细记录(住院)
        private static final String HOS_CHI_MED = "6"; // 中药销售明细记录(住院)
    }


    public void runService () {
        try{
            long startTime = System.currentTimeMillis();
            List<Clinic> clinicList = clinicService.listClinic();
            // 库存同步
//            medicineStoreService.uploadMedicine(clinicList);
//            medicineStoreService.uploadChinaMedicine(clinicList);

            // 入库
//            medicineStorageService.uploadMedicine(clinicList, InStore.MED_PUR);
//            medicineStorageService.uploadMedicine(clinicList, InStore.CHI_MED_PUR);
//            medicineStorageService.uploadMedicine(clinicList, InStore.MED_MED_INBOUND);
//            medicineStorageService.uploadMedicine(clinicList, InStore.CHI_MED_INBOUND);
//            medicineStorageService.uploadMedicine(clinicList, InStore.MED_INV);
//            medicineStorageService.uploadMedicine(clinicList, InStore.CHI_MED_INV);

            //出库
//            medicineReturnService.uploadMedicine(clinicList, OutStore.MED_OUT);
//            medicineReturnService.uploadMedicine(clinicList, OutStore.CHI_MED_OUT);
//            medicineReturnService.uploadMedicine(clinicList, OutStore.MED_OUTTREASURY);
//            medicineReturnService.uploadMedicine(clinicList, OutStore.CHI_MED_OUTTREASURY);
//            medicineReturnService.uploadMedicine(clinicList, OutStore.MED_BACK);
//            medicineReturnService.uploadMedicine(clinicList, OutStore.CHI_MED_BACK);
//            medicineReturnService.uploadMedicine(clinicList, OutStore.MED_INV);
//            medicineReturnService.uploadMedicine(clinicList, OutStore.CHI_MED_INV);

            // 销售明细
//            orderDetailService.uploadMedicine(clinicList, OrderDetail.CLI_MED);
//            orderDetailService.uploadMedicine(clinicList, OrderDetail.CLI_CHI_MED);
//            orderDetailService.uploadMedicine(clinicList, OrderDetail.INS_CLC_MED);
//            orderDetailService.uploadMedicine(clinicList, OrderDetail.INS_CLC_CHI_MED);
            orderDetailService.uploadMedicine(clinicList, OrderDetail.HOS_MED);
//            orderDetailService.uploadMedicine(clinicList, OrderDetail.HOS_CHI_MED);


            long syncTime = System.currentTimeMillis();
            log.info("总耗时--{}", startTime - syncTime);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }

    }


}
